// Function to convert image
function convertImage() {
  const fileInput = document.getElementById("fileInput");
  const formatSelect = document.getElementById("formatSelect");
  const output = document.getElementById("output");
  const errorMessage = document.getElementById("errorMessage");
  const selectedFormat = formatSelect.value;

  // Check if an image is selected
  if (fileInput.files.length === 0) {
    output.innerHTML = "Please select an image.";
    return;
  }

  // Check if a format is selected
  if (selectedFormat === "original") {
    errorMessage.innerText = "Please select a format.";
    return;
  }

  const file = fileInput.files[0];
  const reader = new FileReader();

  // Convert image to selected format
  reader.onload = function (e) {
    const img = new Image();
    img.onload = function () {
      const canvas = document.createElement("canvas");
      canvas.width = img.width;
      canvas.height = img.height;
      const ctx = canvas.getContext("2d");
      ctx.drawImage(img, 0, 0);

      // Get data URL of converted image
      const dataURL = canvas.toDataURL("image/" + selectedFormat); // Dynamically set the format
      output.innerHTML = ""; // Clear previous content
      const convertedImg = document.createElement("img");
      convertedImg.src = dataURL;
      output.appendChild(convertedImg);

      // Add download button
      const downloadButton = document.createElement("button");
      downloadButton.classList.add("download-button");
      downloadButton.innerHTML = "Download";
      downloadButton.addEventListener("click", function () {
        const a = document.createElement("a");
        a.href = dataURL;
        // Set download name with the selected format
        a.download = file.name.replace(/\.[^/.]+$/, "") + "." + selectedFormat;
        a.click();
      });
      output.appendChild(document.createElement("br")); // Line break for separation
      output.appendChild(downloadButton);
    };
    img.src = e.target.result;
  };

  reader.readAsDataURL(file);
}
